@@ -42,7 +42,7 @@ class File:
             delimiter = {'delimiter': sep}
             f = open(url, read_type)
             # csv.register_dialect('my_dialect', **delimiter)
-            cons = csv.reader(f, 'my_dialect', **delimiter)
+            cons = csv.reader(f, **delimiter)
             items = []
             keys = next(cons)
             for c in cons:
